/**
 * @license
 * Copyright 2019 Google LLC
 * SPDX-License-Identifier: BSD-3-Clause
 */
const t = window.ShadowRoot && (void 0 === window.ShadyCSS || window.ShadyCSS.nativeShadow) && "adoptedStyleSheets" in Document.prototype && "replace" in CSSStyleSheet.prototype,e = Symbol(),n = new WeakMap();class s {constructor(t, n, s) {if (this._$cssResult$ = !0, s !== e) throw Error("CSSResult is not constructable. Use `unsafeCSS` or `css` instead.");this.cssText = t, this.t = n;}get styleSheet() {let e = this.o;const s = this.t;if (t && void 0 === e) {const t = void 0 !== s && 1 === s.length;t && (e = n.get(s)), void 0 === e && ((this.o = e = new CSSStyleSheet()).replaceSync(this.cssText), t && n.set(s, e));}return e;}toString() {return this.cssText;}}const o = t => new s("string" == typeof t ? t : t + "", void 0, e),r = (t, ...n) => {const o = 1 === t.length ? t[0] : n.reduce((e, n, s) => e + (t => {if (!0 === t._$cssResult$) return t.cssText;if ("number" == typeof t) return t;throw Error("Value passed to 'css' function must be a 'css' function result: " + t + ". Use 'unsafeCSS' to pass non-literal values, but take care to ensure page security.");})(n) + t[s + 1], t[0]);return new s(o, t, e);},i = (e, n) => {t ? e.adoptedStyleSheets = n.map(t => t instanceof CSSStyleSheet ? t : t.styleSheet) : n.forEach(t => {const n = document.createElement("style"),s = window.litNonce;void 0 !== s && n.setAttribute("nonce", s), n.textContent = t.cssText, e.appendChild(n);});},S = t ? t => t : t => t instanceof CSSStyleSheet ? (t => {let e = "";for (const n of t.cssRules) e += n.cssText;return o(e);})(t) : t;export { s as CSSResult, i as adoptStyles, r as css, S as getCompatibleStyle, t as supportsAdoptingStyleSheets, o as unsafeCSS };